# Bank Feeds API

Bank Feeds API enables your SMB users to set up bank feeds from accounts in your application to supported accounting platforms. 

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-bankfeeds
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatbankfeeds
from codatbankfeeds.models import operations, shared

s = codatbankfeeds.CodatBankFeeds(
    security=shared.Security(
        auth_header="Basic BASE_64_ENCODED(API_KEY)",
    ),
)

req = operations.CreateBankTransactionsRequest(
    create_bank_transactions=shared.CreateBankTransactions(
        account_id='corrupti',
        transactions=[
            shared.CreateBankAccountTransaction(
                amount=7151.9,
                date_='2022-10-23T00:00:00.000Z',
                description='unde',
                id='d8d69a67-4e0f-4467-8c87-96ed151a05df',
            ),
            shared.CreateBankAccountTransaction(
                amount=7781.57,
                date_='2022-10-23T00:00:00.000Z',
                description='at',
                id='df7cc78c-a1ba-4928-bc81-6742cb739205',
            ),
            shared.CreateBankAccountTransaction(
                amount=6176.36,
                date_='2022-10-23T00:00:00.000Z',
                description='iste',
                id='396fea75-96eb-410f-aaa2-352c5955907a',
            ),
        ],
    ),
    account_id='EILBDVJVNUAGVKRQ',
    allow_sync_on_push_complete=False,
    company_id='8a210b68-6988-11ed-a1eb-0242ac120002',
    connection_id='2e9d2c44-f675-40ba-8049-353bfcb5e171',
    timeout_in_minutes=958950,
)

res = s.bank_account_transactions.create(req)

if res.create_bank_transactions_response is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [bank_account_transactions](docs/sdks/bankaccounttransactions/README.md)

* [create](docs/sdks/bankaccounttransactions/README.md#create) - Create bank transactions
* [get](docs/sdks/bankaccounttransactions/README.md#get) - List push options for bank account bank transactions
* [list](docs/sdks/bankaccounttransactions/README.md#list) - List bank transactions for bank account

### [bank_feed_accounts](docs/sdks/bankfeedaccounts/README.md)

* [create](docs/sdks/bankfeedaccounts/README.md#create) - Create bank feed bank accounts
* [get](docs/sdks/bankfeedaccounts/README.md#get) - List bank feed bank accounts
* [update](docs/sdks/bankfeedaccounts/README.md#update) - Update bank feed bank account

### [companies](docs/sdks/companies/README.md)

* [create](docs/sdks/companies/README.md#create) - Create company
* [delete](docs/sdks/companies/README.md#delete) - Delete a company
* [get](docs/sdks/companies/README.md#get) - Get company
* [list](docs/sdks/companies/README.md#list) - List companies
* [update](docs/sdks/companies/README.md#update) - Update company

### [connections](docs/sdks/connections/README.md)

* [create](docs/sdks/connections/README.md#create) - Create connection
* [delete](docs/sdks/connections/README.md#delete) - Delete connection
* [get](docs/sdks/connections/README.md#get) - Get connection
* [list](docs/sdks/connections/README.md#list) - List connections
* [proxy](docs/sdks/connections/README.md#proxy) - Proxy
* [unlink_connection](docs/sdks/connections/README.md#unlink_connection) - Unlink connection
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
